==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/corelibs/U2Script/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>AppContextImpl</name>
    <message>
        <source>UGENE script environment initialization started</source>
        <translation type="vanished">UGENE script environment initialization started</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/CommonDbi.cpp" line="84"/>
        <source>File &quot;%1&quot; does not exist</source>
        <translation>File &quot;%1&quot; does not exist</translation>
    </message>
    <message>
        <location filename="../src/CommonDbi.cpp" line="90"/>
        <source>Could not detect file format</source>
        <translation>Could not detect file format</translation>
    </message>
    <message>
        <location filename="../src/CommonDbi.cpp" line="94"/>
        <source>Importing objects from %1 [%2]</source>
        <translation>Importing objects from %1 [%2]</translation>
    </message>
    <message>
        <location filename="../src/CommonDbi.cpp" line="138"/>
        <source>The unsupported format was provided</source>
        <translation>The unsupported format was provided</translation>
    </message>
    <message>
        <location filename="../src/UgeneContextWrapper.cpp" line="443"/>
        <source>%1-bit version of UGENE started</source>
        <translation>%1-bit version of UGENE started</translation>
    </message>
</context>
<context>
    <name>U2::AppContextImpl</name>
    <message>
        <location filename="../src/UgeneContextWrapper.cpp" line="171"/>
        <source>UGENE script environment initialization started</source>
        <translation type="unfinished">UGENE script environment initialization started</translation>
    </message>
</context>
</TS>

==> ugene_1.20.0%2Bdfsg.orig.tar.xz: ugene-1.20.0/src/corelibs/U2Script/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>AppContextImpl</name>
    <message>
        <source>UGENE script environment initialization started</source>
        <translation type="vanished">UGENE script environment initialization started</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/CommonDbi.cpp" line="84"/>
        <source>File &quot;%1&quot; does not exist</source>
        <translation>File &quot;%1&quot; does not exist</translation>
    </message>
    <message>
        <location filename="../src/CommonDbi.cpp" line="90"/>
        <source>Could not detect file format</source>
        <translation>Could not detect file format</translation>
    </message>
    <message>
        <location filename="../src/CommonDbi.cpp" line="94"/>
        <source>Importing objects from %1 [%2]</source>
        <translation>Importing objects from %1 [%2]</translation>
    </message>
    <message>
        <location filename="../src/CommonDbi.cpp" line="138"/>
        <source>The unsupported format was provided</source>
        <translation>The unsupported format was provided</translation>
    </message>
    <message>
        <location filename="../src/UgeneContextWrapper.cpp" line="443"/>
        <source>%1-bit version of UGENE started</source>
        <translation>%1-bit version of UGENE started</translation>
    </message>
</context>
<context>
    <name>U2::AppContextImpl</name>
    <message>
        <location filename="../src/UgeneContextWrapper.cpp" line="171"/>
        <source>UGENE script environment initialization started</source>
        <translation>UGENE script environment initialization started</translation>
    </message>
</context>
</TS>
